==> haskell-with-location-0.1.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-location.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-location
version:              0.1.0
visibility:           public
id:                   with-location-0.1.0-F6XDWxP6Y8Y5EE1rE1Euee
key:                  with-location-0.1.0-F6XDWxP6Y8Y5EE1rE1Euee
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/with-location#readme
synopsis:
    Use ImplicitParams-based source locations in a backward compatible way

category:             Data
abi:                  dc3798998ace23969f2fe4ae7d55f31f
exposed:              True
exposed-modules:      Data.WithLocation
import-dirs:          /usr/lib/ghc-8.8.1/site-local/with-location-0.1.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/with-location-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/with-location-0.1.0
hs-libraries:         HSwith-location-0.1.0-F6XDWxP6Y8Y5EE1rE1Euee
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-with-location/html/with-location.haddock

haddock-html:         /usr/share/doc/haskell-with-location/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-with-location-0.1.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-with-location.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-location
version:              0.1.0
visibility:           public
id:                   with-location-0.1.0-BOwhd3SHU2fEXsuh8zNz2t
key:                  with-location-0.1.0-BOwhd3SHU2fEXsuh8zNz2t
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/with-location#readme
synopsis:
    Use ImplicitParams-based source locations in a backward compatible way

category:             Data
abi:                  5e8fe6f54215c81c7ca7611957f5ce80
exposed:              True
exposed-modules:      Data.WithLocation
import-dirs:          /usr/lib/ghc-8.8.2/site-local/with-location-0.1.0
library-dirs:         /usr/lib/ghc-8.8.2/site-local/with-location-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/with-location-0.1.0
hs-libraries:         HSwith-location-0.1.0-BOwhd3SHU2fEXsuh8zNz2t
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-with-location/html/with-location.haddock

haddock-html:         /usr/share/doc/haskell-with-location/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
